<?php
/**
 * Class and Function List:
 * Function list:
 * - __construct()
 * - render()
 * - enqueue()
 * - makeGoogleWebfontLink()
 * - makeGoogleWebfontString()
 * - output()
 * - getGoogleArray()
 * - getGoogleFonts()
 * - getSubsets()
 * - getVariants()
 * Classes list:
 * - ReduxFramework_typography
 */

class ReduxFramework_typography {
    
    private $std_fonts = array(
        "Arial, Helvetica, sans-serif" => "Arial, Helvetica, sans-serif",
        "'Arial Black', Gadget, sans-serif" => "'Arial Black', Gadget, sans-serif",
        "'Bookman Old Style', serif" => "'Bookman Old Style', serif",
        "'Comic Sans MS', cursive" => "'Comic Sans MS', cursive",
        "Courier, monospace" => "Courier, monospace",
        "Garamond, serif" => "Garamond, serif",
        "Georgia, serif" => "Georgia, serif",
        "Impact, Charcoal, sans-serif" => "Impact, Charcoal, sans-serif",
        "'Lucida Console', Monaco, monospace" => "'Lucida Console', Monaco, monospace",
        "'Lucida Sans Unicode', 'Lucida Grande', sans-serif" => "'Lucida Sans Unicode', 'Lucida Grande', sans-serif",
        "'MS Sans Serif', Geneva, sans-serif" => "'MS Sans Serif', Geneva, sans-serif",
        "'MS Serif', 'New York', sans-serif" => "'MS Serif', 'New York', sans-serif",
        "'Palatino Linotype', 'Book Antiqua', Palatino, serif" => "'Palatino Linotype', 'Book Antiqua', Palatino, serif",
        "Tahoma,Geneva, sans-serif" => "Tahoma, Geneva, sans-serif",
        "'Times New Roman', Times,serif" => "'Times New Roman', Times, serif",
        "'Trebuchet MS', Helvetica, sans-serif" => "'Trebuchet MS', Helvetica, sans-serif",
        "Verdana, Geneva, sans-serif" => "Verdana, Geneva, sans-serif",
    );
    /**
     * Field Constructor.
     *
     * Required - must call the parent constructor, then assign field and value to vars, and obviously call the render field function
     *
     * @since ReduxFramework 1.0.0
     */
    function __construct($field = array() , $value = '', $parent) {
        
        $this->parent = $parent;
        $this->field = $field;
        $this->value = $value;
    }
    /**
     * Field Render Function.
     *
     * Takes the vars and outputs the HTML for the field in the settings
     *
     * @since ReduxFramework 1.0.0
     */
    function render() {
        
        global $wp_filesystem;
        // Initialize the Wordpress filesystem, no more using file_put_contents function
        if (empty($wp_filesystem)) {
            require_once (ABSPATH . '/wp-admin/includes/file.php');
            WP_Filesystem();
        }
        // No errors please
        $defaults = array(
            'font-family'       => true,
            'font-size'         => true, // true
            'font-weight'       => true,            
            'font-style'        => true,            
            'font-backup'       => false, // false            
            'subsets'           => true,
            'custom_fonts'      => true,
            'text-align'        => true,
            'text-transform'    => false, // false
            'color'             => true,
            'preview'           => true,
            'line-height'       => true, // true
            'word-spacing'      => false, // false
            'letter-spacing'    => false, // false
            'google'            => true,
            'update_weekly'     => false
            // Enable to force updates of Google Fonts to be weekly
            
            
        );
        $this->field = wp_parse_args($this->field, $defaults);
        
        $defaults = array(
            'font-family'       => '',
            'font-options'      => '',
            'font-backup'       => '',
            'text-align'        => '',
            'text-transform'    => '',
            'line-height'       => '',
            'word-spacing'      => '',
            'letter-spacing'    => '',
            'subsets'           => '',
            'google'            => false,
            'font-script'       => '',
            'font-weight'       => '',
            'font-style'        => '',
            'color'             => '',
            'font-size'         => '',
        );
        
        $this->value = wp_parse_args($this->value, $defaults);
        // Since fonts declared is CSS (@font-face) are not rendered in the preview,
        // they can be declared in a CSS file and passed here so they DO display in
        // font preview.  Do NOT pass style.css in your theme, as that will mess up
        // admin page styling.  It's recommended to pass a CSS file with ONLY font
        // declarations.
        
        // If field is set and not blank, then enqueue field
        if (isset($this->field['ext-font-css']) && $this->field['ext-font-css'] != '') {
            wp_register_style('redux-external-fonts', $this->field['ext-font-css']);
            wp_enqueue_style('redux-external-fonts');
        }
        if (empty($this->field['units']) && !empty($this->field['default']['units'])) {
            $this->field['units'] = $this->field['default']['units'];
        }
        if (empty($this->field['units']) || !in_array($this->field['units'], array(
            'px',
            'em',
            'rem',
            '%'
        ))) {
            $this->field['units'] = 'px';
        }
        $unit = $this->field['units'];
        
        echo '<div id="' . $this->field['id'] . '" class="redux-typography-container" data-id="' . $this->field['id'] . '" data-units="' . $unit . '">';
        
        // Open font bar div
        echo '<div class="typography-font-bar">';
        
        if ($this->field['font-family'] === true) {
            /**
             Font Family
             *
             */
            
            if (filter_var($this->value['google'], FILTER_VALIDATE_BOOLEAN)) {
                $fontFamily = explode(', ', $this->value['font-family'], 2);
                if (empty($fontFamily[0]) && !empty($fontFamily[1])) {
                    $fontFamily[0] = $fontFamily[1];
                    $fontFamily[1] = "";
                }
            }
            
            if (!isset($fontFamily)) {
                $fontFamily = array();
                $fontFamily[0] = $this->value['font-family'];
                $fontFamily[1] = "";
            }
            
            echo '<input type="hidden" class="redux-typography-font-family ' . $this->field['class'] . '" name="' . $this->field['name'] . '[font-family]' . $this->field['name_suffix'] . '" value="' . $this->value['font-family'] . '" data-id="' . $this->field['id'] . '"  />';
            echo '<input type="hidden" class="redux-typography-font-options ' . $this->field['class'] . '" name="' . $this->field['name'] . '[font-options]' . $this->field['name_suffix'] . '" value="' . $this->value['font-options'] . '" data-id="' . $this->field['id'] . '"  />';
            echo '<div class="select_wrapper typography-family" style="width: 220px; margin-right: 5px;">';
            echo '<select data-placeholder="' . __('Font family', 'redux-framework') . '" class="redux-typography redux-typography-family ' . $this->field['class'] . '" id="' . $this->field['id'] . '-family" data-id="' . $this->field['id'] . '" data-value="' . $fontFamily[0] . '">';
            echo '<option data-google="false" data-details="" value=""></option>';
            
            if (isset($this->field['update_weekly']) && $this->field['update_weekly'] === true && $this->field['google'] === true && !empty($this->parent->args['google_api_key'])) {
                
                if (file_exists(ReduxFramework::$_dir . 'inc/fields/typography/googlefonts.html')) {
                    // Keep the fonts updated weekly
                    $weekback = strtotime(date('jS F Y', time() + (60 * 60 * 24 * -7)));
                    $last_updated = filemtime(ReduxFramework::$_dir . 'inc/fields/typography/googlefonts.html');
                    if ($last_updated < $weekback) {
                        unlink(ReduxFramework::$_dir . 'inc/fields/typography/googlefonts.html');
                        unlink(ReduxFramework::$_dir . 'inc/fields/typography/googlefonts.json');
                    }
                }
            }
            if (empty($this->field['fonts'])) {
                $this->field['fonts'] = $this->std_fonts;
            }
            // Standard sizes for normal fonts
            $font_sizes = urlencode(json_encode(array(
                '400' => 'Normal 400',
                '700' => 'Bold 700',
                '400italic' => 'Normal 400 Italic',
                '700italic' => 'Bold 700 Italic'
            )));
            
            if (($this->field['google'] == true && !empty($this->parent->args['google_api_key'])) || ($this->field['custom_fonts'] !== false && !empty($this->field['custom_fonts']))) {
                echo '<optgroup label="' . __('Standard Fonts', 'redux-framework') . '">';
            }
            foreach ($this->field['fonts'] as $i => $family) {
                echo '<option data-google="false" data-details="' . $font_sizes . '" value="' . $i . '"' . selected($this->value['font-family'], $i, false) . '>' . $family . '</option>';
            }
            if ($this->field['custom_fonts'] !== false) {
                $this->field['custom_fonts'] = apply_filters("redux/{$this->parent->args['opt_name']}/field/typography/custom_fonts", array());
                if (!empty($this->field['custom_fonts'])) {
                    foreach ($this->field['custom_fonts'] as $group => $fonts) {
                        echo '</optgroup><optgroup label="' . $group . '">';
                        foreach ( $fonts as $family => $v ) {
                            echo '<option data-google="false" data-details="' . $font_sizes . '" value="' . $family . '"' . selected($this->value['font-family'], $family, false) . '>' . $family . '</option>';
                        }
                    }
                }
            }
            
            if ($this->field['google'] == true && !empty($this->parent->args['google_api_key'])) {
                echo '</optgroup>';
                if (!file_exists(ReduxFramework::$_dir . 'inc/fields/typography/googlefonts.html')) {
                    $this->getGoogleFonts();
                }
                if (!isset($this->parent->googleFontHTML) && !empty($this->parent->googleFontHTML)) {
                    echo $this->parent->googleFontHTML;
                } else if (file_exists(ReduxFramework::$_dir . 'inc/fields/typography/googlefonts.html')) {
                    $googleHTML = $wp_filesystem->get_contents(ReduxFramework::$_dir . 'inc/fields/typography/googlefonts.html');
                    // Fallback if file_get_contents won't work for wordpress. MEDIATEMPLE
                    if (empty($googleHTML)) {
                        /*$url = ReduxFramework::$_url . 'inc/fields/typography/googlefonts.html';
                        $ch = curl_init();
                        curl_setopt($ch, CURLOPT_URL, $url);
                        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);*/
                        $googleHTML = '<optgroup label="Google Webfonts"><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="ABeeZee">ABeeZee</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Abel">Abel</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Abril Fatface">Abril Fatface</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Aclonica">Aclonica</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Acme">Acme</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Actor">Actor</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Adamina">Adamina</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22100%22%2C%22name%22%3A%22Ultra-Light+100%22%7D%2C%7B%22id%22%3A%22200%22%2C%22name%22%3A%22Light+200%22%7D%2C%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22500%22%2C%22name%22%3A%22Medium+500%22%7D%2C%7B%22id%22%3A%22600%22%2C%22name%22%3A%22Semi-Bold+600%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22greek%22%2C%22name%22%3A%22Greek%22%7D%5D%7D" data-google="true" value="Advent Pro">Advent Pro</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Aguafina Script">Aguafina Script</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Akronim">Akronim</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Aladin">Aladin</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Aldrich">Aldrich</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Alef">Alef</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22900%22%2C%22name%22%3A%22Ultra-Bold+900%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%2C%7B%22id%22%3A%22900italic%22%2C%22name%22%3A%22Ultra-Bold+900+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Alegreya">Alegreya</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22900%22%2C%22name%22%3A%22Ultra-Bold+900%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%2C%7B%22id%22%3A%22900italic%22%2C%22name%22%3A%22Ultra-Bold+900+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Alegreya SC">Alegreya SC</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22100%22%2C%22name%22%3A%22Ultra-Light+100%22%7D%2C%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22500%22%2C%22name%22%3A%22Medium+500%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22800%22%2C%22name%22%3A%22Extra-Bold+800%22%7D%2C%7B%22id%22%3A%22900%22%2C%22name%22%3A%22Ultra-Bold+900%22%7D%2C%7B%22id%22%3A%22100italic%22%2C%22name%22%3A%22Ultra-Light+100+Italic%22%7D%2C%7B%22id%22%3A%22300italic%22%2C%22name%22%3A%22Book+300+Italic%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22500italic%22%2C%22name%22%3A%22Medium+500+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%2C%7B%22id%22%3A%22800italic%22%2C%22name%22%3A%22Extra-Bold+800+Italic%22%7D%2C%7B%22id%22%3A%22900italic%22%2C%22name%22%3A%22Ultra-Bold+900+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22vietnamese%22%2C%22name%22%3A%22Vietnamese%22%7D%5D%7D" data-google="true" value="Alegreya Sans">Alegreya Sans</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22100%22%2C%22name%22%3A%22Ultra-Light+100%22%7D%2C%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22500%22%2C%22name%22%3A%22Medium+500%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22800%22%2C%22name%22%3A%22Extra-Bold+800%22%7D%2C%7B%22id%22%3A%22900%22%2C%22name%22%3A%22Ultra-Bold+900%22%7D%2C%7B%22id%22%3A%22100italic%22%2C%22name%22%3A%22Ultra-Light+100+Italic%22%7D%2C%7B%22id%22%3A%22300italic%22%2C%22name%22%3A%22Book+300+Italic%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22500italic%22%2C%22name%22%3A%22Medium+500+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%2C%7B%22id%22%3A%22800italic%22%2C%22name%22%3A%22Extra-Bold+800+Italic%22%7D%2C%7B%22id%22%3A%22900italic%22%2C%22name%22%3A%22Ultra-Bold+900+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22vietnamese%22%2C%22name%22%3A%22Vietnamese%22%7D%5D%7D" data-google="true" value="Alegreya Sans SC">Alegreya Sans SC</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Alex Brush">Alex Brush</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Alfa Slab One">Alfa Slab One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Alice">Alice</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Alike">Alike</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Alike Angular">Alike Angular</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Allan">Allan</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Allerta">Allerta</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Allerta Stencil">Allerta Stencil</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Allura">Allura</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Almendra">Almendra</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Almendra Display">Almendra Display</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Almendra SC">Almendra SC</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Amarante">Amarante</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Amaranth">Amaranth</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Amatic SC">Amatic SC</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Amethysta">Amethysta</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Anaheim">Anaheim</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Andada">Andada</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22cyrillic-ext%22%2C%22name%22%3A%22Cyrillic+Extended%22%7D%5D%7D" data-google="true" value="Andika">Andika</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22khmer%22%2C%22name%22%3A%22Khmer%22%7D%5D%7D" data-google="true" value="Angkor">Angkor</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Annie Use Your Telescope">Annie Use Your Telescope</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22cyrillic-ext%22%2C%22name%22%3A%22Cyrillic+Extended%22%7D%2C%7B%22id%22%3A%22greek%22%2C%22name%22%3A%22Greek%22%7D%2C%7B%22id%22%3A%22greek-ext%22%2C%22name%22%3A%22Greek+Extended%22%7D%5D%7D" data-google="true" value="Anonymous Pro">Anonymous Pro</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Antic">Antic</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Antic Didone">Antic Didone</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Antic Slab">Antic Slab</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Anton">Anton</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Arapey">Arapey</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Arbutus">Arbutus</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Arbutus Slab">Arbutus Slab</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Architects Daughter">Architects Daughter</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Archivo Black">Archivo Black</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Archivo Narrow">Archivo Narrow</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22cyrillic-ext%22%2C%22name%22%3A%22Cyrillic+Extended%22%7D%2C%7B%22id%22%3A%22greek%22%2C%22name%22%3A%22Greek%22%7D%2C%7B%22id%22%3A%22vietnamese%22%2C%22name%22%3A%22Vietnamese%22%7D%2C%7B%22id%22%3A%22greek-ext%22%2C%22name%22%3A%22Greek+Extended%22%7D%5D%7D" data-google="true" value="Arimo">Arimo</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Arizonia">Arizonia</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Armata">Armata</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Artifika">Artifika</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Arvo">Arvo</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Asap">Asap</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Asset">Asset</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Astloch">Astloch</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Asul">Asul</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Atomic Age">Atomic Age</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Aubrey">Aubrey</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Audiowide">Audiowide</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Autour One">Autour One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Average">Average</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Average Sans">Average Sans</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Averia Gruesa Libre">Averia Gruesa Libre</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22300italic%22%2C%22name%22%3A%22Book+300+Italic%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Averia Libre">Averia Libre</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22300italic%22%2C%22name%22%3A%22Book+300+Italic%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Averia Sans Libre">Averia Sans Libre</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22300italic%22%2C%22name%22%3A%22Book+300+Italic%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Averia Serif Libre">Averia Serif Libre</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Bad Script">Bad Script</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Balthazar">Balthazar</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Bangers">Bangers</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Basic">Basic</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22khmer%22%2C%22name%22%3A%22Khmer%22%7D%5D%7D" data-google="true" value="Battambang">Battambang</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Baumans">Baumans</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22khmer%22%2C%22name%22%3A%22Khmer%22%7D%5D%7D" data-google="true" value="Bayon">Bayon</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Belgrano">Belgrano</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Belleza">Belleza</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="BenchNine">BenchNine</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Bentham">Bentham</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Berkshire Swash">Berkshire Swash</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Bevan">Bevan</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Bigelow Rules">Bigelow Rules</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Bigshot One">Bigshot One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Bilbo">Bilbo</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Bilbo Swash Caps">Bilbo Swash Caps</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Bitter">Bitter</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Black Ops One">Black Ops One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22khmer%22%2C%22name%22%3A%22Khmer%22%7D%5D%7D" data-google="true" value="Bokor">Bokor</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Bonbon">Bonbon</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Boogaloo">Boogaloo</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Bowlby One">Bowlby One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Bowlby One SC">Bowlby One SC</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Brawler">Brawler</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Bree Serif">Bree Serif</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Bubblegum Sans">Bubblegum Sans</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Bubbler One">Bubbler One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Buda">Buda</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Buenard">Buenard</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Butcherman">Butcherman</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Butterfly Kids">Butterfly Kids</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22500%22%2C%22name%22%3A%22Medium+500%22%7D%2C%7B%22id%22%3A%22600%22%2C%22name%22%3A%22Semi-Bold+600%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22500italic%22%2C%22name%22%3A%22Medium+500+Italic%22%7D%2C%7B%22id%22%3A%22600italic%22%2C%22name%22%3A%22Semi-Bold+600+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Cabin">Cabin</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22500%22%2C%22name%22%3A%22Medium+500%22%7D%2C%7B%22id%22%3A%22600%22%2C%22name%22%3A%22Semi-Bold+600%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Cabin Condensed">Cabin Condensed</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Cabin Sketch">Cabin Sketch</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Caesar Dressing">Caesar Dressing</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Cagliostro">Cagliostro</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Calligraffitti">Calligraffitti</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Cambo">Cambo</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Candal">Candal</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Cantarell">Cantarell</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Cantata One">Cantata One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Cantora One">Cantora One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Capriola">Capriola</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22greek%22%2C%22name%22%3A%22Greek%22%7D%2C%7B%22id%22%3A%22greek-ext%22%2C%22name%22%3A%22Greek+Extended%22%7D%5D%7D" data-google="true" value="Cardo">Cardo</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Carme">Carme</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Carrois Gothic">Carrois Gothic</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Carrois Gothic SC">Carrois Gothic SC</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Carter One">Carter One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22greek%22%2C%22name%22%3A%22Greek%22%7D%2C%7B%22id%22%3A%22greek-ext%22%2C%22name%22%3A%22Greek+Extended%22%7D%5D%7D" data-google="true" value="Caudex">Caudex</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Cedarville Cursive">Cedarville Cursive</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Ceviche One">Ceviche One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Changa One">Changa One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Chango">Chango</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Chau Philomene One">Chau Philomene One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Chela One">Chela One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Chelsea Market">Chelsea Market</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22khmer%22%2C%22name%22%3A%22Khmer%22%7D%5D%7D" data-google="true" value="Chenla">Chenla</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Cherry Cream Soda">Cherry Cream Soda</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Cherry Swash">Cherry Swash</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Chewy">Chewy</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Chicle">Chicle</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22900%22%2C%22name%22%3A%22Ultra-Bold+900%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22900italic%22%2C%22name%22%3A%22Ultra-Bold+900+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Chivo">Chivo</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22900%22%2C%22name%22%3A%22Ultra-Bold+900%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Cinzel">Cinzel</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22900%22%2C%22name%22%3A%22Ultra-Bold+900%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Cinzel Decorative">Cinzel Decorative</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Clicker Script">Clicker Script</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22800%22%2C%22name%22%3A%22Extra-Bold+800%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Coda">Coda</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22800%22%2C%22name%22%3A%22Extra-Bold+800%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Coda Caption">Coda Caption</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Codystar">Codystar</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Combo">Combo</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22cyrillic-ext%22%2C%22name%22%3A%22Cyrillic+Extended%22%7D%2C%7B%22id%22%3A%22greek%22%2C%22name%22%3A%22Greek%22%7D%5D%7D" data-google="true" value="Comfortaa">Comfortaa</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Coming Soon">Coming Soon</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Concert One">Concert One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Condiment">Condiment</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22khmer%22%2C%22name%22%3A%22Khmer%22%7D%5D%7D" data-google="true" value="Content">Content</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Contrail One">Contrail One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Convergence">Convergence</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Cookie">Cookie</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Copse">Copse</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Corben">Corben</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Courgette">Courgette</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22cyrillic-ext%22%2C%22name%22%3A%22Cyrillic+Extended%22%7D%2C%7B%22id%22%3A%22greek%22%2C%22name%22%3A%22Greek%22%7D%2C%7B%22id%22%3A%22vietnamese%22%2C%22name%22%3A%22Vietnamese%22%7D%2C%7B%22id%22%3A%22greek-ext%22%2C%22name%22%3A%22Greek+Extended%22%7D%5D%7D" data-google="true" value="Cousine">Cousine</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22900%22%2C%22name%22%3A%22Ultra-Bold+900%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Coustard">Coustard</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Covered By Your Grace">Covered By Your Grace</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Crafty Girls">Crafty Girls</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Creepster">Creepster</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Crete Round">Crete Round</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22600%22%2C%22name%22%3A%22Semi-Bold+600%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22600italic%22%2C%22name%22%3A%22Semi-Bold+600+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Crimson Text">Crimson Text</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Croissant One">Croissant One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Crushed">Crushed</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Cuprum">Cuprum</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Cutive">Cutive</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Cutive Mono">Cutive Mono</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Damion">Damion</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Dancing Script">Dancing Script</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22khmer%22%2C%22name%22%3A%22Khmer%22%7D%5D%7D" data-google="true" value="Dangrek">Dangrek</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Dawning of a New Day">Dawning of a New Day</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Days One">Days One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Delius">Delius</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Delius Swash Caps">Delius Swash Caps</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Delius Unicase">Delius Unicase</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Della Respira">Della Respira</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Denk One">Denk One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Devonshire">Devonshire</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22cyrillic-ext%22%2C%22name%22%3A%22Cyrillic+Extended%22%7D%2C%7B%22id%22%3A%22greek%22%2C%22name%22%3A%22Greek%22%7D%2C%7B%22id%22%3A%22greek-ext%22%2C%22name%22%3A%22Greek+Extended%22%7D%5D%7D" data-google="true" value="Didact Gothic">Didact Gothic</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Diplomata">Diplomata</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Diplomata SC">Diplomata SC</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Domine">Domine</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Donegal One">Donegal One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Doppio One">Doppio One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Dorsa">Dorsa</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22200%22%2C%22name%22%3A%22Light+200%22%7D%2C%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22500%22%2C%22name%22%3A%22Medium+500%22%7D%2C%7B%22id%22%3A%22600%22%2C%22name%22%3A%22Semi-Bold+600%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22800%22%2C%22name%22%3A%22Extra-Bold+800%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Dosis">Dosis</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Dr Sugiyama">Dr Sugiyama</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Droid Sans">Droid Sans</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Droid Sans Mono">Droid Sans Mono</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Droid Serif">Droid Serif</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Duru Sans">Duru Sans</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Dynalight">Dynalight</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22cyrillic-ext%22%2C%22name%22%3A%22Cyrillic+Extended%22%7D%2C%7B%22id%22%3A%22vietnamese%22%2C%22name%22%3A%22Vietnamese%22%7D%5D%7D" data-google="true" value="EB Garamond">EB Garamond</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Eagle Lake">Eagle Lake</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Eater">Eater</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Economica">Economica</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Electrolize">Electrolize</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22900%22%2C%22name%22%3A%22Ultra-Bold+900%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Elsie">Elsie</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22900%22%2C%22name%22%3A%22Ultra-Bold+900%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Elsie Swash Caps">Elsie Swash Caps</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Emblema One">Emblema One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Emilys Candy">Emilys Candy</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Engagement">Engagement</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Englebert">Englebert</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Enriqueta">Enriqueta</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Erica One">Erica One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Esteban">Esteban</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Euphoria Script">Euphoria Script</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Ewert">Ewert</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22100%22%2C%22name%22%3A%22Ultra-Light+100%22%7D%2C%7B%22id%22%3A%22200%22%2C%22name%22%3A%22Light+200%22%7D%2C%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22500%22%2C%22name%22%3A%22Medium+500%22%7D%2C%7B%22id%22%3A%22600%22%2C%22name%22%3A%22Semi-Bold+600%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22800%22%2C%22name%22%3A%22Extra-Bold+800%22%7D%2C%7B%22id%22%3A%22900%22%2C%22name%22%3A%22Ultra-Bold+900%22%7D%2C%7B%22id%22%3A%22100italic%22%2C%22name%22%3A%22Ultra-Light+100+Italic%22%7D%2C%7B%22id%22%3A%22200italic%22%2C%22name%22%3A%22Light+200+Italic%22%7D%2C%7B%22id%22%3A%22300italic%22%2C%22name%22%3A%22Book+300+Italic%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22500italic%22%2C%22name%22%3A%22Medium+500+Italic%22%7D%2C%7B%22id%22%3A%22600italic%22%2C%22name%22%3A%22Semi-Bold+600+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%2C%7B%22id%22%3A%22800italic%22%2C%22name%22%3A%22Extra-Bold+800+Italic%22%7D%2C%7B%22id%22%3A%22900italic%22%2C%22name%22%3A%22Ultra-Bold+900+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Exo">Exo</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22100%22%2C%22name%22%3A%22Ultra-Light+100%22%7D%2C%7B%22id%22%3A%22200%22%2C%22name%22%3A%22Light+200%22%7D%2C%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22500%22%2C%22name%22%3A%22Medium+500%22%7D%2C%7B%22id%22%3A%22600%22%2C%22name%22%3A%22Semi-Bold+600%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22800%22%2C%22name%22%3A%22Extra-Bold+800%22%7D%2C%7B%22id%22%3A%22900%22%2C%22name%22%3A%22Ultra-Bold+900%22%7D%2C%7B%22id%22%3A%22100italic%22%2C%22name%22%3A%22Ultra-Light+100+Italic%22%7D%2C%7B%22id%22%3A%22200italic%22%2C%22name%22%3A%22Light+200+Italic%22%7D%2C%7B%22id%22%3A%22300italic%22%2C%22name%22%3A%22Book+300+Italic%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22500italic%22%2C%22name%22%3A%22Medium+500+Italic%22%7D%2C%7B%22id%22%3A%22600italic%22%2C%22name%22%3A%22Semi-Bold+600+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%2C%7B%22id%22%3A%22800italic%22%2C%22name%22%3A%22Extra-Bold+800+Italic%22%7D%2C%7B%22id%22%3A%22900italic%22%2C%22name%22%3A%22Ultra-Bold+900+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Exo 2">Exo 2</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22500%22%2C%22name%22%3A%22Medium+500%22%7D%2C%7B%22id%22%3A%22600%22%2C%22name%22%3A%22Semi-Bold+600%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22500italic%22%2C%22name%22%3A%22Medium+500+Italic%22%7D%2C%7B%22id%22%3A%22600italic%22%2C%22name%22%3A%22Semi-Bold+600+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Expletus Sans">Expletus Sans</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Fanwood Text">Fanwood Text</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Fascinate">Fascinate</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Fascinate Inline">Fascinate Inline</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Faster One">Faster One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22khmer%22%2C%22name%22%3A%22Khmer%22%7D%5D%7D" data-google="true" value="Fasthand">Fasthand</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Fauna One">Fauna One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Federant">Federant</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Federo">Federo</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Felipa">Felipa</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Fenix">Fenix</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Finger Paint">Finger Paint</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Fjalla One">Fjalla One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Fjord One">Fjord One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Flamenco">Flamenco</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Flavors">Flavors</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Fondamento">Fondamento</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Fontdiner Swanky">Fontdiner Swanky</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22cyrillic-ext%22%2C%22name%22%3A%22Cyrillic+Extended%22%7D%5D%7D" data-google="true" value="Forum">Forum</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Francois One">Francois One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Freckle Face">Freckle Face</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Fredericka the Great">Fredericka the Great</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Fredoka One">Fredoka One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22khmer%22%2C%22name%22%3A%22Khmer%22%7D%5D%7D" data-google="true" value="Freehand">Freehand</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Fresca">Fresca</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Frijole">Frijole</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Fruktur">Fruktur</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Fugaz One">Fugaz One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22greek%22%2C%22name%22%3A%22Greek%22%7D%5D%7D" data-google="true" value="GFS Didot">GFS Didot</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22greek%22%2C%22name%22%3A%22Greek%22%7D%5D%7D" data-google="true" value="GFS Neohellenic">GFS Neohellenic</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Gabriela">Gabriela</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Gafata">Gafata</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Galdeano">Galdeano</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Galindo">Galindo</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Gentium Basic">Gentium Basic</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Gentium Book Basic">Gentium Book Basic</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Geo">Geo</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Geostar">Geostar</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Geostar Fill">Geostar Fill</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Germania One">Germania One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Gilda Display">Gilda Display</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Give You Glory">Give You Glory</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Glass Antiqua">Glass Antiqua</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Glegoo">Glegoo</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Gloria Hallelujah">Gloria Hallelujah</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Goblin One">Goblin One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Gochi Hand">Gochi Hand</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Gorditas">Gorditas</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Goudy Bookletter 1911">Goudy Bookletter 1911</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Graduate">Graduate</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Grand Hotel">Grand Hotel</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Gravitas One">Gravitas One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Great Vibes">Great Vibes</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Griffy">Griffy</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Gruppo">Gruppo</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Gudea">Gudea</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Habibi">Habibi</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Hammersmith One">Hammersmith One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Hanalei">Hanalei</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Hanalei Fill">Hanalei Fill</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Handlee">Handlee</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22khmer%22%2C%22name%22%3A%22Khmer%22%7D%5D%7D" data-google="true" value="Hanuman">Hanuman</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Happy Monkey">Happy Monkey</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Headland One">Headland One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Henny Penny">Henny Penny</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Herr Von Muellerhoff">Herr Von Muellerhoff</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Holtwood One SC">Holtwood One SC</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Homemade Apple">Homemade Apple</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Homenaje">Homenaje</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="IM Fell DW Pica">IM Fell DW Pica</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="IM Fell DW Pica SC">IM Fell DW Pica SC</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="IM Fell Double Pica">IM Fell Double Pica</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="IM Fell Double Pica SC">IM Fell Double Pica SC</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="IM Fell English">IM Fell English</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="IM Fell English SC">IM Fell English SC</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="IM Fell French Canon">IM Fell French Canon</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="IM Fell French Canon SC">IM Fell French Canon SC</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="IM Fell Great Primer">IM Fell Great Primer</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="IM Fell Great Primer SC">IM Fell Great Primer SC</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Iceberg">Iceberg</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Iceland">Iceland</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Imprima">Imprima</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Inconsolata">Inconsolata</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Inder">Inder</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Indie Flower">Indie Flower</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Inika">Inika</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Irish Grover">Irish Grover</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22cyrillic-ext%22%2C%22name%22%3A%22Cyrillic+Extended%22%7D%5D%7D" data-google="true" value="Istok Web">Istok Web</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Italiana">Italiana</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Italianno">Italianno</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Jacques Francois">Jacques Francois</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Jacques Francois Shadow">Jacques Francois Shadow</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Jim Nightshade">Jim Nightshade</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Jockey One">Jockey One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Jolly Lodger">Jolly Lodger</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22100%22%2C%22name%22%3A%22Ultra-Light+100%22%7D%2C%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22600%22%2C%22name%22%3A%22Semi-Bold+600%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22100italic%22%2C%22name%22%3A%22Ultra-Light+100+Italic%22%7D%2C%7B%22id%22%3A%22300italic%22%2C%22name%22%3A%22Book+300+Italic%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22600italic%22%2C%22name%22%3A%22Semi-Bold+600+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Josefin Sans">Josefin Sans</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22100%22%2C%22name%22%3A%22Ultra-Light+100%22%7D%2C%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22600%22%2C%22name%22%3A%22Semi-Bold+600%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22100italic%22%2C%22name%22%3A%22Ultra-Light+100+Italic%22%7D%2C%7B%22id%22%3A%22300italic%22%2C%22name%22%3A%22Book+300+Italic%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22600italic%22%2C%22name%22%3A%22Semi-Bold+600+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Josefin Slab">Josefin Slab</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Joti One">Joti One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Judson">Judson</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Julee">Julee</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Julius Sans One">Julius Sans One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Junge">Junge</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22500%22%2C%22name%22%3A%22Medium+500%22%7D%2C%7B%22id%22%3A%22600%22%2C%22name%22%3A%22Semi-Bold+600%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22cyrillic-ext%22%2C%22name%22%3A%22Cyrillic+Extended%22%7D%2C%7B%22id%22%3A%22greek%22%2C%22name%22%3A%22Greek%22%7D%2C%7B%22id%22%3A%22greek-ext%22%2C%22name%22%3A%22Greek+Extended%22%7D%5D%7D" data-google="true" value="Jura">Jura</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Just Another Hand">Just Another Hand</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Just Me Again Down Here">Just Me Again Down Here</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Kameron">Kameron</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22khmer%22%2C%22name%22%3A%22Khmer%22%7D%5D%7D" data-google="true" value="Kantumruy">Kantumruy</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Karla">Karla</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Kaushan Script">Kaushan Script</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Kavoon">Kavoon</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22khmer%22%2C%22name%22%3A%22Khmer%22%7D%5D%7D" data-google="true" value="Kdam Thmor">Kdam Thmor</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Keania One">Keania One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Kelly Slab">Kelly Slab</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Kenia">Kenia</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22khmer%22%2C%22name%22%3A%22Khmer%22%7D%5D%7D" data-google="true" value="Khmer">Khmer</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Kite One">Kite One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Knewave">Knewave</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Kotta One">Kotta One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22khmer%22%2C%22name%22%3A%22Khmer%22%7D%5D%7D" data-google="true" value="Koulen">Koulen</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Kranky">Kranky</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Kreon">Kreon</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Kristi">Kristi</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Krona One">Krona One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="La Belle Aurore">La Belle Aurore</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Lancelot">Lancelot</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22100%22%2C%22name%22%3A%22Ultra-Light+100%22%7D%2C%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22900%22%2C%22name%22%3A%22Ultra-Bold+900%22%7D%2C%7B%22id%22%3A%22100italic%22%2C%22name%22%3A%22Ultra-Light+100+Italic%22%7D%2C%7B%22id%22%3A%22300italic%22%2C%22name%22%3A%22Book+300+Italic%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%2C%7B%22id%22%3A%22900italic%22%2C%22name%22%3A%22Ultra-Bold+900+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Lato">Lato</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="League Script">League Script</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Leckerli One">Leckerli One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Ledger">Ledger</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Lekton">Lekton</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Lemon">Lemon</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Libre Baskerville">Libre Baskerville</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Life Savers">Life Savers</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Lilita One">Lilita One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Lily Script One">Lily Script One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Limelight">Limelight</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Linden Hill">Linden Hill</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22cyrillic-ext%22%2C%22name%22%3A%22Cyrillic+Extended%22%7D%5D%7D" data-google="true" value="Lobster">Lobster</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Lobster Two">Lobster Two</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Londrina Outline">Londrina Outline</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Londrina Shadow">Londrina Shadow</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Londrina Sketch">Londrina Sketch</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Londrina Solid">Londrina Solid</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Lora">Lora</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Love Ya Like A Sister">Love Ya Like A Sister</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Loved by the King">Loved by the King</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Lovers Quarrel">Lovers Quarrel</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Luckiest Guy">Luckiest Guy</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Lusitana">Lusitana</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Lustria">Lustria</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Macondo">Macondo</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Macondo Swash Caps">Macondo Swash Caps</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Magra">Magra</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Maiden Orange">Maiden Orange</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Mako">Mako</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Marcellus">Marcellus</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Marcellus SC">Marcellus SC</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Marck Script">Marck Script</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Margarine">Margarine</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Marko One">Marko One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Marmelad">Marmelad</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Marvel">Marvel</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Mate">Mate</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Mate SC">Mate SC</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22500%22%2C%22name%22%3A%22Medium+500%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22900%22%2C%22name%22%3A%22Ultra-Bold+900%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Maven Pro">Maven Pro</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="McLaren">McLaren</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Meddon">Meddon</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="MedievalSharp">MedievalSharp</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Medula One">Medula One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Megrim">Megrim</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Meie Script">Meie Script</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Merienda">Merienda</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Merienda One">Merienda One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22900%22%2C%22name%22%3A%22Ultra-Bold+900%22%7D%2C%7B%22id%22%3A%22300italic%22%2C%22name%22%3A%22Book+300+Italic%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%2C%7B%22id%22%3A%22900italic%22%2C%22name%22%3A%22Ultra-Bold+900+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Merriweather">Merriweather</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22800%22%2C%22name%22%3A%22Extra-Bold+800%22%7D%2C%7B%22id%22%3A%22300italic%22%2C%22name%22%3A%22Book+300+Italic%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%2C%7B%22id%22%3A%22800italic%22%2C%22name%22%3A%22Extra-Bold+800+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Merriweather Sans">Merriweather Sans</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22khmer%22%2C%22name%22%3A%22Khmer%22%7D%5D%7D" data-google="true" value="Metal">Metal</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Metal Mania">Metal Mania</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Metamorphous">Metamorphous</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Metrophobic">Metrophobic</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Michroma">Michroma</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Milonga">Milonga</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Miltonian">Miltonian</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Miltonian Tattoo">Miltonian Tattoo</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Miniver">Miniver</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Miss Fajardose">Miss Fajardose</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Modern Antiqua">Modern Antiqua</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Molengo">Molengo</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Molle">Molle</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Monda">Monda</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Monofett">Monofett</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Monoton">Monoton</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Monsieur La Doulaise">Monsieur La Doulaise</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Montaga">Montaga</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Montez">Montez</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Montserrat">Montserrat</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Montserrat Alternates">Montserrat Alternates</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Montserrat Subrayada">Montserrat Subrayada</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22khmer%22%2C%22name%22%3A%22Khmer%22%7D%5D%7D" data-google="true" value="Moul">Moul</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22khmer%22%2C%22name%22%3A%22Khmer%22%7D%5D%7D" data-google="true" value="Moulpali">Moulpali</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Mountains of Christmas">Mountains of Christmas</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Mouse Memoirs">Mouse Memoirs</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Mr Bedfort">Mr Bedfort</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Mr Dafoe">Mr Dafoe</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Mr De Haviland">Mr De Haviland</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Mrs Saint Delafield">Mrs Saint Delafield</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Mrs Sheppards">Mrs Sheppards</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22300italic%22%2C%22name%22%3A%22Book+300+Italic%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Muli">Muli</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Mystery Quest">Mystery Quest</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Neucha">Neucha</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22200%22%2C%22name%22%3A%22Light+200%22%7D%2C%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22800%22%2C%22name%22%3A%22Extra-Bold+800%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Neuton">Neuton</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="New Rocker">New Rocker</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="News Cycle">News Cycle</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Niconne">Niconne</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Nixie One">Nixie One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Nobile">Nobile</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22khmer%22%2C%22name%22%3A%22Khmer%22%7D%5D%7D" data-google="true" value="Nokora">Nokora</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Norican">Norican</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Nosifer">Nosifer</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Nothing You Could Do">Nothing You Could Do</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22vietnamese%22%2C%22name%22%3A%22Vietnamese%22%7D%5D%7D" data-google="true" value="Noticia Text">Noticia Text</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22devanagari%22%2C%22name%22%3A%22Devanagari%22%7D%2C%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22cyrillic-ext%22%2C%22name%22%3A%22Cyrillic+Extended%22%7D%2C%7B%22id%22%3A%22greek%22%2C%22name%22%3A%22Greek%22%7D%2C%7B%22id%22%3A%22vietnamese%22%2C%22name%22%3A%22Vietnamese%22%7D%2C%7B%22id%22%3A%22greek-ext%22%2C%22name%22%3A%22Greek+Extended%22%7D%5D%7D" data-google="true" value="Noto Sans">Noto Sans</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22cyrillic-ext%22%2C%22name%22%3A%22Cyrillic+Extended%22%7D%2C%7B%22id%22%3A%22greek%22%2C%22name%22%3A%22Greek%22%7D%2C%7B%22id%22%3A%22vietnamese%22%2C%22name%22%3A%22Vietnamese%22%7D%2C%7B%22id%22%3A%22greek-ext%22%2C%22name%22%3A%22Greek+Extended%22%7D%5D%7D" data-google="true" value="Noto Serif">Noto Serif</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Nova Cut">Nova Cut</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Nova Flat">Nova Flat</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22greek%22%2C%22name%22%3A%22Greek%22%7D%5D%7D" data-google="true" value="Nova Mono">Nova Mono</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Nova Oval">Nova Oval</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Nova Round">Nova Round</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Nova Script">Nova Script</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Nova Slim">Nova Slim</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Nova Square">Nova Square</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Numans">Numans</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Nunito">Nunito</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22khmer%22%2C%22name%22%3A%22Khmer%22%7D%5D%7D" data-google="true" value="Odor Mean Chey">Odor Mean Chey</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Offside">Offside</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Old Standard TT">Old Standard TT</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Oldenburg">Oldenburg</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Oleo Script">Oleo Script</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Oleo Script Swash Caps">Oleo Script Swash Caps</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22600%22%2C%22name%22%3A%22Semi-Bold+600%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22800%22%2C%22name%22%3A%22Extra-Bold+800%22%7D%2C%7B%22id%22%3A%22300italic%22%2C%22name%22%3A%22Book+300+Italic%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22600italic%22%2C%22name%22%3A%22Semi-Bold+600+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%2C%7B%22id%22%3A%22800italic%22%2C%22name%22%3A%22Extra-Bold+800+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22devanagari%22%2C%22name%22%3A%22Devanagari%22%7D%2C%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22cyrillic-ext%22%2C%22name%22%3A%22Cyrillic+Extended%22%7D%2C%7B%22id%22%3A%22greek%22%2C%22name%22%3A%22Greek%22%7D%2C%7B%22id%22%3A%22vietnamese%22%2C%22name%22%3A%22Vietnamese%22%7D%2C%7B%22id%22%3A%22greek-ext%22%2C%22name%22%3A%22Greek+Extended%22%7D%5D%7D" data-google="true" value="Open Sans">Open Sans</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22300italic%22%2C%22name%22%3A%22Book+300+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22cyrillic-ext%22%2C%22name%22%3A%22Cyrillic+Extended%22%7D%2C%7B%22id%22%3A%22greek%22%2C%22name%22%3A%22Greek%22%7D%2C%7B%22id%22%3A%22vietnamese%22%2C%22name%22%3A%22Vietnamese%22%7D%2C%7B%22id%22%3A%22greek-ext%22%2C%22name%22%3A%22Greek+Extended%22%7D%5D%7D" data-google="true" value="Open Sans Condensed">Open Sans Condensed</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22cyrillic-ext%22%2C%22name%22%3A%22Cyrillic+Extended%22%7D%5D%7D" data-google="true" value="Oranienbaum">Oranienbaum</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22500%22%2C%22name%22%3A%22Medium+500%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22900%22%2C%22name%22%3A%22Ultra-Bold+900%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Orbitron">Orbitron</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Oregano">Oregano</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Orienta">Orienta</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Original Surfer">Original Surfer</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Oswald">Oswald</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Over the Rainbow">Over the Rainbow</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22900%22%2C%22name%22%3A%22Ultra-Bold+900%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%2C%7B%22id%22%3A%22900italic%22%2C%22name%22%3A%22Ultra-Bold+900+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Overlock">Overlock</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Overlock SC">Overlock SC</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Ovo">Ovo</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Oxygen">Oxygen</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Oxygen Mono">Oxygen Mono</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22cyrillic-ext%22%2C%22name%22%3A%22Cyrillic+Extended%22%7D%5D%7D" data-google="true" value="PT Mono">PT Mono</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22cyrillic-ext%22%2C%22name%22%3A%22Cyrillic+Extended%22%7D%5D%7D" data-google="true" value="PT Sans">PT Sans</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22cyrillic-ext%22%2C%22name%22%3A%22Cyrillic+Extended%22%7D%5D%7D" data-google="true" value="PT Sans Caption">PT Sans Caption</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22cyrillic-ext%22%2C%22name%22%3A%22Cyrillic+Extended%22%7D%5D%7D" data-google="true" value="PT Sans Narrow">PT Sans Narrow</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22cyrillic-ext%22%2C%22name%22%3A%22Cyrillic+Extended%22%7D%5D%7D" data-google="true" value="PT Serif">PT Serif</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22cyrillic-ext%22%2C%22name%22%3A%22Cyrillic+Extended%22%7D%5D%7D" data-google="true" value="PT Serif Caption">PT Serif Caption</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Pacifico">Pacifico</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Paprika">Paprika</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Parisienne">Parisienne</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Passero One">Passero One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22900%22%2C%22name%22%3A%22Ultra-Bold+900%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Passion One">Passion One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Pathway Gothic One">Pathway Gothic One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22vietnamese%22%2C%22name%22%3A%22Vietnamese%22%7D%5D%7D" data-google="true" value="Patrick Hand">Patrick Hand</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22vietnamese%22%2C%22name%22%3A%22Vietnamese%22%7D%5D%7D" data-google="true" value="Patrick Hand SC">Patrick Hand SC</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Patua One">Patua One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Paytone One">Paytone One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Peralta">Peralta</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Permanent Marker">Permanent Marker</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Petit Formal Script">Petit Formal Script</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Petrona">Petrona</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Philosopher">Philosopher</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Piedra">Piedra</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Pinyon Script">Pinyon Script</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Pirata One">Pirata One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Plaster">Plaster</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22cyrillic-ext%22%2C%22name%22%3A%22Cyrillic+Extended%22%7D%2C%7B%22id%22%3A%22greek%22%2C%22name%22%3A%22Greek%22%7D%2C%7B%22id%22%3A%22greek-ext%22%2C%22name%22%3A%22Greek+Extended%22%7D%5D%7D" data-google="true" value="Play">Play</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Playball">Playball</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22900%22%2C%22name%22%3A%22Ultra-Bold+900%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%2C%7B%22id%22%3A%22900italic%22%2C%22name%22%3A%22Ultra-Bold+900+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Playfair Display">Playfair Display</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22900%22%2C%22name%22%3A%22Ultra-Bold+900%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%2C%7B%22id%22%3A%22900italic%22%2C%22name%22%3A%22Ultra-Bold+900+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Playfair Display SC">Playfair Display SC</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Podkova">Podkova</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Poiret One">Poiret One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Poller One">Poller One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Poly">Poly</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Pompiere">Pompiere</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Pontano Sans">Pontano Sans</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Port Lligat Sans">Port Lligat Sans</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Port Lligat Slab">Port Lligat Slab</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Prata">Prata</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22khmer%22%2C%22name%22%3A%22Khmer%22%7D%5D%7D" data-google="true" value="Preahvihear">Preahvihear</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22greek%22%2C%22name%22%3A%22Greek%22%7D%5D%7D" data-google="true" value="Press Start 2P">Press Start 2P</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Princess Sofia">Princess Sofia</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Prociono">Prociono</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Prosto One">Prosto One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Puritan">Puritan</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Purple Purse">Purple Purse</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Quando">Quando</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Quantico">Quantico</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Quattrocento">Quattrocento</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Quattrocento Sans">Quattrocento Sans</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Questrial">Questrial</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Quicksand">Quicksand</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Quintessential">Quintessential</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Qwigley">Qwigley</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Racing Sans One">Racing Sans One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Radley">Radley</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22100%22%2C%22name%22%3A%22Ultra-Light+100%22%7D%2C%7B%22id%22%3A%22200%22%2C%22name%22%3A%22Light+200%22%7D%2C%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22500%22%2C%22name%22%3A%22Medium+500%22%7D%2C%7B%22id%22%3A%22600%22%2C%22name%22%3A%22Semi-Bold+600%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22800%22%2C%22name%22%3A%22Extra-Bold+800%22%7D%2C%7B%22id%22%3A%22900%22%2C%22name%22%3A%22Ultra-Bold+900%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Raleway">Raleway</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Raleway Dots">Raleway Dots</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Rambla">Rambla</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Rammetto One">Rammetto One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Ranchers">Ranchers</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Rancho">Rancho</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Rationale">Rationale</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Redressed">Redressed</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Reenie Beanie">Reenie Beanie</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Revalia">Revalia</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Ribeye">Ribeye</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Ribeye Marrow">Ribeye Marrow</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Righteous">Righteous</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Risque">Risque</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22100%22%2C%22name%22%3A%22Ultra-Light+100%22%7D%2C%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22500%22%2C%22name%22%3A%22Medium+500%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22900%22%2C%22name%22%3A%22Ultra-Bold+900%22%7D%2C%7B%22id%22%3A%22100italic%22%2C%22name%22%3A%22Ultra-Light+100+Italic%22%7D%2C%7B%22id%22%3A%22300italic%22%2C%22name%22%3A%22Book+300+Italic%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22500italic%22%2C%22name%22%3A%22Medium+500+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%2C%7B%22id%22%3A%22900italic%22%2C%22name%22%3A%22Ultra-Bold+900+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22cyrillic-ext%22%2C%22name%22%3A%22Cyrillic+Extended%22%7D%2C%7B%22id%22%3A%22greek%22%2C%22name%22%3A%22Greek%22%7D%2C%7B%22id%22%3A%22vietnamese%22%2C%22name%22%3A%22Vietnamese%22%7D%2C%7B%22id%22%3A%22greek-ext%22%2C%22name%22%3A%22Greek+Extended%22%7D%5D%7D" data-google="true" value="Roboto">Roboto</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22300italic%22%2C%22name%22%3A%22Book+300+Italic%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22cyrillic-ext%22%2C%22name%22%3A%22Cyrillic+Extended%22%7D%2C%7B%22id%22%3A%22greek%22%2C%22name%22%3A%22Greek%22%7D%2C%7B%22id%22%3A%22vietnamese%22%2C%22name%22%3A%22Vietnamese%22%7D%2C%7B%22id%22%3A%22greek-ext%22%2C%22name%22%3A%22Greek+Extended%22%7D%5D%7D" data-google="true" value="Roboto Condensed">Roboto Condensed</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22100%22%2C%22name%22%3A%22Ultra-Light+100%22%7D%2C%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22cyrillic-ext%22%2C%22name%22%3A%22Cyrillic+Extended%22%7D%2C%7B%22id%22%3A%22greek%22%2C%22name%22%3A%22Greek%22%7D%2C%7B%22id%22%3A%22vietnamese%22%2C%22name%22%3A%22Vietnamese%22%7D%2C%7B%22id%22%3A%22greek-ext%22%2C%22name%22%3A%22Greek+Extended%22%7D%5D%7D" data-google="true" value="Roboto Slab">Roboto Slab</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Rochester">Rochester</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Rock Salt">Rock Salt</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Rokkitt">Rokkitt</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Romanesco">Romanesco</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Ropa Sans">Ropa Sans</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Rosario">Rosario</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Rosarivo">Rosarivo</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Rouge Script">Rouge Script</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22900%22%2C%22name%22%3A%22Ultra-Bold+900%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Ruda">Ruda</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Rufina">Rufina</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Ruge Boogie">Ruge Boogie</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Ruluko">Ruluko</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Rum Raisin">Rum Raisin</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22cyrillic-ext%22%2C%22name%22%3A%22Cyrillic+Extended%22%7D%5D%7D" data-google="true" value="Ruslan Display">Ruslan Display</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Russo One">Russo One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Ruthie">Ruthie</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Rye">Rye</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Sacramento">Sacramento</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Sail">Sail</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Salsa">Salsa</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Sanchez">Sanchez</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Sancreek">Sancreek</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Sansita One">Sansita One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Sarina">Sarina</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Satisfy">Satisfy</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Scada">Scada</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Schoolbell">Schoolbell</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Seaweed Script">Seaweed Script</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Sevillana">Sevillana</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Seymour One">Seymour One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Shadows Into Light">Shadows Into Light</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Shadows Into Light Two">Shadows Into Light Two</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Shanti">Shanti</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Share">Share</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Share Tech">Share Tech</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Share Tech Mono">Share Tech Mono</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Shojumaru">Shojumaru</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Short Stack">Short Stack</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22khmer%22%2C%22name%22%3A%22Khmer%22%7D%5D%7D" data-google="true" value="Siemreap">Siemreap</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Sigmar One">Sigmar One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22600%22%2C%22name%22%3A%22Semi-Bold+600%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Signika">Signika</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22600%22%2C%22name%22%3A%22Semi-Bold+600%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Signika Negative">Signika Negative</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22900%22%2C%22name%22%3A%22Ultra-Bold+900%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22900italic%22%2C%22name%22%3A%22Ultra-Bold+900+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Simonetta">Simonetta</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Sintony">Sintony</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Sirin Stencil">Sirin Stencil</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Six Caps">Six Caps</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Skranji">Skranji</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Slackey">Slackey</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Smokum">Smokum</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Smythe">Smythe</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22800%22%2C%22name%22%3A%22Extra-Bold+800%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Sniglet">Sniglet</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Snippet">Snippet</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Snowburst One">Snowburst One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Sofadi One">Sofadi One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Sofia">Sofia</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Sonsie One">Sonsie One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Sorts Mill Goudy">Sorts Mill Goudy</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22200%22%2C%22name%22%3A%22Light+200%22%7D%2C%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22500%22%2C%22name%22%3A%22Medium+500%22%7D%2C%7B%22id%22%3A%22600%22%2C%22name%22%3A%22Semi-Bold+600%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22900%22%2C%22name%22%3A%22Ultra-Bold+900%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Source Code Pro">Source Code Pro</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22200%22%2C%22name%22%3A%22Light+200%22%7D%2C%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22600%22%2C%22name%22%3A%22Semi-Bold+600%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22900%22%2C%22name%22%3A%22Ultra-Bold+900%22%7D%2C%7B%22id%22%3A%22200italic%22%2C%22name%22%3A%22Light+200+Italic%22%7D%2C%7B%22id%22%3A%22300italic%22%2C%22name%22%3A%22Book+300+Italic%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22600italic%22%2C%22name%22%3A%22Semi-Bold+600+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%2C%7B%22id%22%3A%22900italic%22%2C%22name%22%3A%22Ultra-Bold+900+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22vietnamese%22%2C%22name%22%3A%22Vietnamese%22%7D%5D%7D" data-google="true" value="Source Sans Pro">Source Sans Pro</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Special Elite">Special Elite</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Spicy Rice">Spicy Rice</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Spinnaker">Spinnaker</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Spirax">Spirax</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Squada One">Squada One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Stalemate">Stalemate</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Stalinist One">Stalinist One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Stardos Stencil">Stardos Stencil</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Stint Ultra Condensed">Stint Ultra Condensed</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Stint Ultra Expanded">Stint Ultra Expanded</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Stoke">Stoke</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Strait">Strait</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Sue Ellen Francisco">Sue Ellen Francisco</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Sunshiney">Sunshiney</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Supermercado One">Supermercado One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22khmer%22%2C%22name%22%3A%22Khmer%22%7D%5D%7D" data-google="true" value="Suwannaphum">Suwannaphum</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Swanky and Moo Moo">Swanky and Moo Moo</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Syncopate">Syncopate</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Tangerine">Tangerine</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22khmer%22%2C%22name%22%3A%22Khmer%22%7D%5D%7D" data-google="true" value="Taprom">Taprom</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Tauri">Tauri</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Telex">Telex</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22cyrillic-ext%22%2C%22name%22%3A%22Cyrillic+Extended%22%7D%5D%7D" data-google="true" value="Tenor Sans">Tenor Sans</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Text Me One">Text Me One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="The Girl Next Door">The Girl Next Door</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22900%22%2C%22name%22%3A%22Ultra-Bold+900%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Tienne">Tienne</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22cyrillic-ext%22%2C%22name%22%3A%22Cyrillic+Extended%22%7D%2C%7B%22id%22%3A%22greek%22%2C%22name%22%3A%22Greek%22%7D%2C%7B%22id%22%3A%22vietnamese%22%2C%22name%22%3A%22Vietnamese%22%7D%2C%7B%22id%22%3A%22greek-ext%22%2C%22name%22%3A%22Greek+Extended%22%7D%5D%7D" data-google="true" value="Tinos">Tinos</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Titan One">Titan One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22200%22%2C%22name%22%3A%22Light+200%22%7D%2C%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22600%22%2C%22name%22%3A%22Semi-Bold+600%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22900%22%2C%22name%22%3A%22Ultra-Bold+900%22%7D%2C%7B%22id%22%3A%22200italic%22%2C%22name%22%3A%22Light+200+Italic%22%7D%2C%7B%22id%22%3A%22300italic%22%2C%22name%22%3A%22Book+300+Italic%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22600italic%22%2C%22name%22%3A%22Semi-Bold+600+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Titillium Web">Titillium Web</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Trade Winds">Trade Winds</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Trocchi">Trocchi</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Trochut">Trochut</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Trykker">Trykker</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Tulpen One">Tulpen One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22500%22%2C%22name%22%3A%22Medium+500%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22300italic%22%2C%22name%22%3A%22Book+300+Italic%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22500italic%22%2C%22name%22%3A%22Medium+500+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22cyrillic-ext%22%2C%22name%22%3A%22Cyrillic+Extended%22%7D%2C%7B%22id%22%3A%22greek%22%2C%22name%22%3A%22Greek%22%7D%2C%7B%22id%22%3A%22greek-ext%22%2C%22name%22%3A%22Greek+Extended%22%7D%5D%7D" data-google="true" value="Ubuntu">Ubuntu</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22cyrillic-ext%22%2C%22name%22%3A%22Cyrillic+Extended%22%7D%2C%7B%22id%22%3A%22greek%22%2C%22name%22%3A%22Greek%22%7D%2C%7B%22id%22%3A%22greek-ext%22%2C%22name%22%3A%22Greek+Extended%22%7D%5D%7D" data-google="true" value="Ubuntu Condensed">Ubuntu Condensed</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%2C%7B%22id%22%3A%22cyrillic-ext%22%2C%22name%22%3A%22Cyrillic+Extended%22%7D%2C%7B%22id%22%3A%22greek%22%2C%22name%22%3A%22Greek%22%7D%2C%7B%22id%22%3A%22greek-ext%22%2C%22name%22%3A%22Greek+Extended%22%7D%5D%7D" data-google="true" value="Ubuntu Mono">Ubuntu Mono</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Ultra">Ultra</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Uncial Antiqua">Uncial Antiqua</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Underdog">Underdog</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Unica One">Unica One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="UnifrakturCook">UnifrakturCook</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="UnifrakturMaguntia">UnifrakturMaguntia</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Unkempt">Unkempt</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Unlock">Unlock</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Unna">Unna</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="VT323">VT323</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Vampiro One">Vampiro One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Varela">Varela</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Varela Round">Varela Round</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Vast Shadow">Vast Shadow</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Vibur">Vibur</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Vidaloka">Vidaloka</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Viga">Viga</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Voces">Voces</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Volkhov">Volkhov</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%2C%7B%22id%22%3A%22400italic%22%2C%22name%22%3A%22Normal+400+Italic%22%7D%2C%7B%22id%22%3A%22700italic%22%2C%22name%22%3A%22Bold+700+Italic%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Vollkorn">Vollkorn</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Voltaire">Voltaire</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Waiting for the Sunrise">Waiting for the Sunrise</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Wallpoet">Wallpoet</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Walter Turncoat">Walter Turncoat</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Warnes">Warnes</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Wellfleet">Wellfleet</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Wendy One">Wendy One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Wire One">Wire One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22200%22%2C%22name%22%3A%22Light+200%22%7D%2C%7B%22id%22%3A%22300%22%2C%22name%22%3A%22Book+300%22%7D%2C%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%2C%7B%22id%22%3A%22700%22%2C%22name%22%3A%22Bold+700%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Yanone Kaffeesatz">Yanone Kaffeesatz</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Yellowtail">Yellowtail</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22cyrillic%22%2C%22name%22%3A%22Cyrillic%22%7D%2C%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%2C%7B%22id%22%3A%22latin-ext%22%2C%22name%22%3A%22Latin+Extended%22%7D%5D%7D" data-google="true" value="Yeseva One">Yeseva One</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Yesteryear">Yesteryear</option><option data-details="%7B%22variants%22%3A%5B%7B%22id%22%3A%22400%22%2C%22name%22%3A%22Normal+400%22%7D%5D%2C%22subsets%22%3A%5B%7B%22id%22%3A%22latin%22%2C%22name%22%3A%22Latin%22%7D%5D%7D" data-google="true" value="Zeyada">Zeyada</option></optgroup>';
                       // curl_close($ch);
						
						$user_agent = $res['headers']['user-agent'];
                        if (empty($googleHTML)) {
                            $googleHTML = false;
                        }
                    }
                    $this->parent->googleFontHTML = $googleHTML;
                    echo $googleHTML;
                }
            }
            
            echo '</select></div>';
            
            if ($this->field['google'] === true) {
                // Set a flag so we know to set a header style or not
                echo '<input type="hidden" class="redux-typography-google' . $this->field['class'] . '" id="' . $this->field['id'] . '-google" name="' . $this->field['name'] . '[google]' . $this->field['name_suffix'] . '" type="text" value="' . $this->field['google'] . '" data-id="' . $this->field['id'] . '" />';
            }
        }
        
        /**
         Backup Font
         *
         */
        if ($this->field['font-family'] === true && $this->field['google'] === true) {
            // Set a flag so we know to set a header style or not
            echo '<input type="hidden" class="redux-typography-google' . $this->field['class'] . '" id="' . $this->field['id'] . '-google" name="' . $this->field['name'] . '[google]' . $this->field['name_suffix'] . '" type="text" value="' . $this->field['google'] . '" data-id="' . $this->field['id'] . '" data-id="' . $this->field['id'] . '"  />';
            
            if ($this->field['font-backup'] === true) {
                echo '<div class="select_wrapper typography-family-backup" style="width: 220px; margin-right: 5px;">';
                echo '<select data-placeholder="' . __('Backup Font Family', 'redux-framework') . '" name="' . $this->field['name'] . '[font-backup]' . $this->field['name_suffix'] . '" class="redux-typography redux-typography-family-backup ' . $this->field['class'] . '" id="' . $this->field['id'] . '-family-backup" data-id="' . $this->field['id'] . '" data-value="' . $this->value['font-backup'] . '">';
                echo '<option data-google="false" data-details="" value=""></option>';
                foreach ($this->field['fonts'] as $i => $family) {
                    echo '<option data-google="true" data-details="' . $font_sizes . '" value="' . $i . '"' . selected($this->value['font-backup'], $i, false) . '>' . $family . '</option>';
                }
                echo '</select></div>';
            }
        }
        
        // Close font-bar div
        echo '</div>';
        
        // Open style bar div
        echo '<div class="typography-style-bar">';
        
        /**
         Font Style/Weight
         *
         */
        if ($this->field['font-style'] === true || $this->field['font-weight'] === true):
            echo '<div class="select_wrapper typography-style" original-title="' . __('Font style', 'redux-framework') . '">';
            $style = $this->value['font-weight'] . $this->value['font-style'];
            echo '<input type="hidden" class="typography-font-weight" name="' . $this->field['name'] . '[font-weight]' . $this->field['name_suffix'] . '" val="' . $this->value['font-weight'] . '" data-id="' . $this->field['id'] . '"  /> ';
            echo '<input type="hidden" class="typography-font-style" name="' . $this->field['name'] . '[font-style]' . $this->field['name_suffix'] . '" val="' . $this->value['font-style'] . '" data-id="' . $this->field['id'] . '"  /> ';
            echo '<select data-placeholder="' . __('Style', 'redux-framework') . '" class="redux-typography redux-typography-style select' . $this->field['class'] . '" original-title="' . __('Font style', 'redux-framework') . '" id="' . $this->field['id'] . '_style" data-id="' . $this->field['id'] . '" data-value="' . $style . '">';
            if (empty($this->value['subset'])) {
                echo '<option value=""></option>';
            }
            $nonGStyles = array(
                '200' => 'Lighter',
                '400' => 'Normal',
                '700' => 'Bold',
                '900' => 'Bolder'
            );
            if (isset($gfonts[$this->value['font-family']])) {
                foreach ($gfonts[$this->value['font-family']]['variants'] as $v) {
                    echo '<option value="' . $v['id'] . '" ' . selected($this->value['subset'], $v['id'], false) . '>' . $v['name'] . '</option>';
                }
            } else {
                foreach ($nonGStyles as $i => $style) {
                    if (!isset($this->value['subset'])) $this->value['subset'] = false;
                    echo '<option value="' . $i . '" ' . selected($this->value['subset'], $i, false) . '>' . $style . '</option>';
                }
            }
            
            echo '</select></div>';
        endif;
        
        /**
         Font Script
         *
         */
        if ($this->field['font-family'] === true && $this->field['subsets'] === true && $this->field['google'] === true):
            echo '<div class="select_wrapper typography-script tooltip" original-title="' . __('Font subsets', 'redux-framework') . '">';
            echo '<select data-placeholder="' . __('Subsets', 'redux-framework') . '" class="redux-typography redux-typography-subsets' . $this->field['class'] . '" original-title="' . __('Font script', 'redux-framework') . '"  id="' . $this->field['id'] . '-subsets" name="' . $this->field['name'] . '[subsets]' . $this->field['name_suffix'] . '" data-value="' . $this->value['subsets'] . '" data-id="' . $this->field['id'] . '" >';
            if (empty($this->value['subsets'])) {
                echo '<option value=""></option>';
            }
            if (isset($gfonts[$this->value['font-family']])) {
                foreach ($gfonts[$this->value['font-family']]['subsets'] as $v) {
                    echo '<option value="' . $v['id'] . '" ' . selected($this->value['subset'], $v['id'], false) . '>' . $v['name'] . '</option>';
                }
            }
            echo '</select></div>';
        endif;
        
        /**
         Font Align
         *
         */
        if ($this->field['text-align'] === true):
            echo '<div class="select_wrapper typography-align tooltip" original-title="' . __('Text Align', 'redux-framework') . '">';
            echo '<select data-placeholder="' . __('Text Align', 'redux-framework') . '" class="redux-typography redux-typography-align' . $this->field['class'] . '" original-title="' . __('Text Align', 'redux-framework') . '"  id="' . $this->field['id'] . '-align" name="' . $this->field['name'] . '[text-align]' . $this->field['name_suffix'] . '" data-value="' . $this->value['text-align'] . '" data-id="' . $this->field['id'] . '" >';
            echo '<option value=""></option>';
            $align = array(
                'inherit',
                'left',
                'right',
                'center',
                'justify',
                'initial'
            );
            
            foreach ($align as $v) {
                echo '<option value="' . $v . '" ' . selected($this->value['text-align'], $v, false) . '>' . ucfirst($v) . '</option>';
            }
            
            echo '</select></div>';
        endif;

        /**
         Text Transform
         *
         */        
        if ($this->field['text-transform'] === true){
            echo '<div class="select_wrapper typography-transform tooltip" original-title="' . __('Text Transform', 'redux-framework') . '">';
            echo '<select data-placeholder="' . __('Text Transform', 'redux-framework') . '" class="redux-typography redux-typography-transform' . $this->field['class'] . '" original-title="' . __('Text Transform', 'redux-framework') . '"  id="' . $this->field['id'] . '-transform" name="' . $this->field['name'] . '[text-transform]' . $this->field['name_suffix'] . '" data-value="' . $this->value['text-transform'] . '" data-id="' . $this->field['id'] . '" >';
            echo '<option value=""></option>';
            $values = array(
                'none',
                'capitalize',
                'uppercase',
                'lowercase',
                'initial',
                'inherit'
            );
            
            foreach ($values as $v) {
                echo '<option value="' . $v . '" ' . selected($this->value['text-transform'], $v, false) . '>' . ucfirst($v) . '</option>';
            }
            
            echo '</select></div>';
        }

        // Close style bar div
        echo '</div>';
        
        // Open size-bar div
        echo '<div class="typography-size-bar">';
        
        /**
         Font Size
         *
         */
        if ($this->field['font-size'] === true):
            echo '<div class="input-append"><input type="text" qtip-tip="Size" class="span2 redux-typography redux-typography-size mini' . $this->field['class'] . ' redux-typography-qtip" title="' . __('Size', 'redux-framework') . '" placeholder="' . __('Size', 'redux-framework') . '" id="' . $this->field['id'] . '-size" name="' . $this->field['name'] . '[font-size]' . $this->field['name_suffix'] . '" value="' . str_replace($unit, '', $this->value['font-size']) . '" data-value="' . str_replace($unit, '', $this->value['font-size']) . '"><span class="add-on">' . $unit . '</span></div>';
            echo '<input type="hidden" class="typography-font-size" name="' . $this->field['name'] . '[font-size]" value="' . $this->value['font-size'] . '" data-id="' . $this->field['id'] . '"  />';
        endif;
        /**
         Line Height
         *
         */
        if ($this->field['line-height'] === true):
            echo '<div class="input-append"><input type="text" qtip-tip="Height" class="span2 redux-typography redux-typography-height mini' . $this->field['class'] . ' redux-typography-qtip" title="' . __('Height', 'redux-framework') . '" placeholder="' . __('Height', 'redux-framework') . '" id="' . $this->field['id'] . '-height" value="' . str_replace($unit, '', $this->value['line-height']) . '" data-value="' . str_replace($unit, '', $this->value['line-height']) . '"><span class="add-on">' . $unit . '</span></div>';
            echo '<input type="hidden" class="typography-line-height" name="' . $this->field['name'] . '[line-height]' . $this->field['name_suffix'] . '" value="' . $this->value['line-height'] . '" data-id="' . $this->field['id'] . '"  />';
        endif;
        /**
         Word Spacing
         *
         */
        if ($this->field['word-spacing'] === true):
            echo '<div class="input-append"><input type="text" qtip-tip="Word Spacing" class="span2 redux-typography redux-typography-qtip redux-typography-word mini' . $this->field['class'] . '" placeholder="' . __('Word Spacing', 'redux-framework') . '" id="' . $this->field['id'] . '-word" value="' . str_replace($unit, '', $this->value['word-spacing']) . '" data-value="' . str_replace($unit, '', $this->value['word-spacing']) . '"><span class="add-on">' . $unit . '</span></div>';
            echo '<input type="hidden" class="typography-word-spacing" name="' . $this->field['name'] . '[word-spacing]' . $this->field['name_suffix'] . '" value="' . $this->value['word-spacing'] . '" data-id="' . $this->field['id'] . '"  />';
        endif;
        
        /**
         Letter Spacing
         *
         */
        if ($this->field['letter-spacing'] === true):
            echo '<div class="input-append"><input type="text" qtip-tip="Letter Spacing" class="span2 redux-typography-qtip redux-typography redux-typography-letter mini' . $this->field['class'] . '" placeholder="' . __('Letter Spacing', 'redux-framework') . '" id="' . $this->field['id'] . '-letter" value="' . str_replace($unit, '', $this->value['letter-spacing']) . '" data-value="' . str_replace($unit, '', $this->value['letter-spacing']) . '"><span class="add-on">' . $unit . '</span></div>';
            echo '<input type="hidden" class="typography-letter-spacing" name="' . $this->field['name'] . '[letter-spacing]' . $this->field['name_suffix'] . '" value="' . $this->value['letter-spacing'] . '" data-id="' . $this->field['id'] . '"  />';
        endif;
        
        
        /**
         Font Color
         *
         */
        if ($this->field['color'] === true):
            $default = "";
            if (empty($this->field['default']['color']) && !empty($this->field['color'])) {
                $default = $this->value['color'];
            } else if (!empty($this->field['default']['color'])) {
                $default = $this->field['default']['color'];
            }
            echo '<div id="' . $this->field['id'] . '_color_picker" class="colorSelector typography-color"><div style="background-color: ' . $this->value['color'] . '"></div></div>';
            echo '<input data-default-color="' . $default . '" class="redux-color redux-typography-color' . $this->field['class'] . '" original-title="' . __('Font color', 'redux-framework') . '" id="' . $this->field['id'] . '-color" name="' . $this->field['name'] . '[color]' . $this->field['name_suffix'] . '" type="text" value="' . $this->value['color'] . '" data-id="' . $this->field['id'] . '" />';
        endif;
        
        // Close size-bar div
        echo '</div>';
        
        /**
         Font Preview
         *
         */
        if (!isset($this->field['preview']) || $this->field['preview'] !== false):
            if (isset($this->field['preview']['text'])) {
                $g_text = $this->field['preview']['text'];
            } else {
                $g_text = '1 2 3 4 5 6 7 8 9 0 A B C D E F G H I J K L M N O P Q R S T U V W X Y Z a b c d e f g h i j k l m n o p q r s t u v w x y z';
            }
            if (isset($this->field['preview']['font-size'])) {
                $g_size = 'style="font-size: ' . $this->field['preview']['font-size'] . ';"';
            } else {
                $g_size = '';
            }
            
            echo '<p class="clear ' . $this->field['id'] . '_previewer typography-preview" ' . $g_size . '>' . $g_text . '</p>';
            echo "</div>";
        endif;
    } //function
    
    
    /**
     * Enqueue Function.
     *
     * If this field requires any scripts, or css define this function and register/enqueue the scripts/css
     *
     * @since ReduxFramework 1.0.0
     */
    function enqueue() {
        
        wp_enqueue_script('redux-field-color-js', ReduxFramework::$_url . 'inc/fields/color/field_color.js', array(
            'jquery',
            'wp-color-picker'
        ) , time() , true);
        
        wp_enqueue_style('redux-field-color-css', ReduxFramework::$_url . 'inc/fields/color/field_color.css', time() , true);
        
        wp_enqueue_script('redux-field-typography-js', ReduxFramework::$_url . 'inc/fields/typography/field_typography.js', array(
            'jquery',
            'wp-color-picker',
            'redux-field-color-js',
            'select2-js'
        ) , time() , true);
        
        wp_enqueue_style('redux-field-typography-css', ReduxFramework::$_url . 'inc/fields/typography/field_typography.css', time() , true);
    } //function
    
    
    /**
     * makeGoogleWebfontLink Function.
     *
     * Creates the google fonts link.
     *
     * @since ReduxFramework 3.0.0
     */
    function makeGoogleWebfontLink($fonts) {
        $link = "";
        $subsets = array();
        foreach ($fonts as $family => $font) {
            if (!empty($link)) {
                $link.= "%7C"; // Append a new font to the string
                
                
            }
            $link.= $family;
            
            if (!empty($font['font-style'])) {
                $link.= ':';
                if (!empty($font['all-styles'])) {
                    $link.= implode(',', $font['all-styles']);
                } else if (!empty($font['font-style'])) {
                    $link.= implode(',', $font['font-style']);
                }
            }
            if (!empty($font['subset'])) {
                foreach ($font['subset'] as $subset) {
                    if (!in_array($subset, $subsets)) {
                        array_push($subsets, $subset);
                    }
                }
            }
        }
        if (!empty($subsets)) {
            $link.= "&amp;subset=" . implode(',', $subsets);
        }
        
        return '//fonts.googleapis.com/css?family=' . $link;
    }
    /**
     * makeGoogleWebfontString Function.
     *
     * Creates the google fonts link.
     *
     * @since ReduxFramework 3.1.8
     */
    function makeGoogleWebfontString($fonts) {
        $link = "";
        $subsets = array();
        foreach ($fonts as $family => $font) {
            if (!empty($link)) {
                $link.= "', '"; // Append a new font to the string
                
                
            }
            $link.= $family;
            
            if (!empty($font['font-style'])) {
                $link.= ':';
                if (!empty($font['all-styles'])) {
                    $link.= implode(',', $font['all-styles']);
                } else if (!empty($font['font-style'])) {
                    $link.= implode(',', $font['font-style']);
                }
            }
            if (!empty($font['subset'])) {
                foreach ($font['subset'] as $subset) {
                    if (!in_array($subset, $subsets)) {
                        array_push($subsets, $subset);
                    }
                }
            }
        }
        if (!empty($subsets)) {
            $link.= "&amp;subset=" . implode(',', $subsets);
        }
        
        return "'" . $link . "'";
    }
    
    function output() {
        
        global $wp_styles;
        
        $font = $this->value;
        // Check for font-backup.  If it's set, stick it on a variabhle for
        // later use.
        if (!empty($font['font-family']) && !empty($font['font-backup'])) {
            $font['font-family'] = str_replace(', ' . $font['font-backup'], '', $font['font-family']);
            $fontBackup = ',' . $font['font-backup'];
        }
        
        $style = '';
        if (!empty($font)) {
            foreach ($font as $key => $value) {
                if ($key == 'font-options') {
                    continue;
                }
                // Check for font-family key
                if ('font-family' == $key) {
                    // Ensure fontBackup isn't empty (we already option
                    // checked this earlier.  No need to do it again.
                    if (!empty($fontBackup)) {
                        // Apply the backup font to the font-family element
                        // via the saved variable.  We do this here so it
                        // doesn't get appended to the Google stuff below.
                        $value.= $fontBackup;
                    }
                }
                
                if (empty($value) && in_array($key, array(
                    'font-weight',
                    'font-style'
                ))) {
                    $value = "normal";
                }
                
                if ($key == "google" || $key == "subsets" || $key == "font-backup" || empty($value)) {
                    continue;
                }
                $style.= $key . ':' . $value . ';';
            }
        }
        
        if (!empty($style)) {
            if (!empty($this->field['output']) && is_array($this->field['output'])) {
                $keys = implode(",", $this->field['output']);
                $this->parent->outputCSS.= $keys . "{" . $style . '}';
            }
            
            if (!empty($this->field['compiler']) && is_array($this->field['compiler'])) {
                $keys = implode(",", $this->field['compiler']);
                $this->parent->compilerCSS.= $keys . "{" . $style . '}';
            }
        }
        // Google only stuff!
        if (!empty($this->parent->args['google_api_key']) && !empty($font['font-family']) && !empty($this->field['google']) && filter_var($this->field['google'], FILTER_VALIDATE_BOOLEAN)) {
            // Added standard font matching check to avoid output to Google fonts call - kp
            
            // If no custom font array was supplied, the load it with default
            // standard fonts.
            if (empty($this->field['fonts'])) {
                $this->field['fonts'] = $this->std_fonts;
            }
            // Ensure the fonts array is NOT empty
            if (!empty($this->field['fonts'])) {
                //Make the font keys in the array lowercase, for case-insensitive matching
                $lcFonts = array_change_key_case($this->field['fonts']);
                // Rebuild font array with all keys stripped of spaces
                $arr = array();
                foreach ($lcFonts as $key => $value) {
                    $key = str_replace(', ', ',', $key);
                    $arr[$key] = $value;
                }
                $lcFonts = $arr;
                unset($arr);
                // lowercase chosen font for matching purposes
                $lcFont = strtolower($font['font-family']);
                // Remove spaces after commas in chosen font for mathcing purposes.
                $lcFont = str_replace(', ', ',', $lcFont);
                // If the lower cased passed font-family is NOT found in the standard font array
                // Then it's a Google font, so process it for output.
                if (!array_key_exists($lcFont, $lcFonts)) {
                    $family = $font['font-family'];
                    // Strip out spaces in font names and replace with with plus signs
                    // TODO?: This method doesn't respect spaces after commas, hence the reason
                    // for the std_font array keys having no spaces after commas.  This could be
                    // fixed with RegEx in the future.
                    $font['font-family'] = str_replace(' ', '+', $font['font-family']);
                    // Push data to parent typography variable.
                    if (empty($this->parent->typography[$font['font-family']])) {
                        $this->parent->typography[$font['font-family']] = array();
                    }
                    
                    if (isset($this->field['all_styles'])) {
                        if (!isset($font['font-options'])) {
                            $this->getGoogleArray();
                            if (isset($this->parent->googleArray) && !empty($this->parent->googleArray) && isset($this->parent->googleArray[$family])) {
                                $font['font-options'] = $this->parent->googleArray[$family];
                            }
                        } else {
                            $font['font-options'] = json_decode($font['font-options'], true);
                        }
                    }
                    
                    if (isset($font['font-options']) && !empty($font['font-options']) && isset($this->field['all_styles']) && filter_var($this->field['all_styles'], FILTER_VALIDATE_BOOLEAN)) {
                        if (isset($font['font-options']) && !empty($font['font-options']['variants'])) {
                            if (!isset($this->parent->typography[$font['font-family']]['all-styles']) || empty($this->parent->typography[$font['font-family']]['all-styles'])) {
                                $this->parent->typography[$font['font-family']]['all-styles'] = array();
                                foreach ($font['font-options']['variants'] as $variant) {
                                    $this->parent->typography[$font['font-family']]['all-styles'][] = $variant['id'];
                                }
                            }
                        }
                    }
                    if (!empty($font['font-weight'])) {
                        if (empty($this->parent->typography[$font['font-family']]['font-weight']) || !in_array($font['font-weight'], $this->parent->typography[$font['font-family']]['font-weight'])) {
                            $style = $font['font-weight'];
                        }
                        if (!empty($font['font-style'])) {
                            $style.= $font['font-style'];
                        }
                        
                        if (empty($this->parent->typography[$font['font-family']]['font-style']) || !in_array($style, $this->parent->typography[$font['font-family']]['font-style'])) {
                            $this->parent->typography[$font['font-family']]['font-style'][] = $style;
                        }
                    }
                    
                    if (!empty($font['subsets'])) {
                        if (empty($this->parent->typography[$font['font-family']]['subset']) || !in_array($font['subsets'], $this->parent->typography[$font['font-family']]['subset'])) {
                            $this->parent->typography[$font['font-family']]['subset'][] = $font['subsets'];
                        }
                    }
                } // !array_key_exists
                
                
            } //!empty fonts array
            
            
        } // Typography not set
        //print_r($this->parent->typography);
        
        
    }
    /**
     *
     *   Construct the google array from the stored JSON/HTML
     *
     */
    function getGoogleArray() {
        
        global $wp_filesystem;
        // Initialize the Wordpress filesystem, no more using file_put_contents function
        if (empty($wp_filesystem)) {
            require_once (ABSPATH . '/wp-admin/includes/file.php');
            WP_Filesystem();
        }
        
        if (isset($this->parent->googleArray) && !empty($this->parent->googleArray)) {
            return;
        }
        
        if (!file_exists(ReduxFramework::$_dir . 'inc/fields/typography/googlefonts.json')) {
            
            $result = wp_remote_get(apply_filters('redux-google-fonts-api-url', 'https://www.googleapis.com/webfonts/v1/webfonts?key=') . $this->parent->args['google_api_key'], array( 'sslverify' => false ));
            
            if (!is_wp_error($result) && $result['response']['code'] == 200) {
                $result = json_decode($result['body']);
                foreach ($result->items as $font) {
                    $this->parent->googleArray[$font->family] = array(
                        'variants' => $this->getVariants($font->variants) ,
                        'subsets' => $this->getSubsets($font->subsets)
                    );
                }
                
                if (!empty($this->parent->googleArray)) {
                    $wp_filesystem->put_contents(ReduxFramework::$_dir . 'inc/fields/typography/googlefonts.json', json_encode($this->parent->googleArray) , FS_CHMOD_FILE
                    // predefined mode settings for WP files
                    );
                }
            } //if
            
            
        } //if
        
        if (!isset($this->parent->googleArray) || empty($this->parent->googleArray)) {
            $this->parent->googleArray = json_decode($wp_filesystem->get_contents(ReduxFramework::$_dir . 'inc/fields/typography/googlefonts.json') , true);
        }
    }
    /**
     * getGoogleFonts Function.
     *
     * Used to retrieve Google Web Fonts from their API
     *
     * @since ReduxFramework 0.2.0
     */
    function getGoogleFonts() {
        
        global $wp_filesystem;
        
        $this->getGoogleArray();
        
        if (!isset($this->parent->googleArray) || empty($this->parent->googleArray)) {
            return;
        }
        
        $gfonts = '<optgroup label="' . __('Google Webfonts', 'redux-framework') . '">';
        foreach ($this->parent->googleArray as $i => $face) {
            $gfonts.= '<option data-details="' . urlencode(json_encode($face)) . '" data-google="true" value="' . $i . '">' . $i . '</option>';
        }
        $gfonts.= '</optgroup>';
        //endif;
        if (empty($this->parent->googleArray)) {
            $gfonts = "";
        }
        
        $wp_filesystem->put_contents(ReduxFramework::$_dir . 'inc/fields/typography/googlefonts.html', $gfonts, FS_CHMOD_FILE
        // predefined mode settings for WP files
        );
    } //function
    
    
    /**
     * getGoogleFonts Function.
     *
     * Clean up the Google Webfonts subsets to be human readable
     *
     * @since ReduxFramework 0.2.0
     */
    function getSubsets($var) {
        $result = array();
        foreach ($var as $v) {
            if (strpos($v, "-ext")) {
                $name = ucfirst(str_replace("-ext", " Extended", $v));
            } else {
                $name = ucfirst($v);
            }
            array_push($result, array(
                'id' => $v,
                'name' => $name
            ));
        }
        return array_filter($result);
    } //function
    
    
    /**
     * getGoogleFonts Function.
     *
     * Clean up the Google Webfonts variants to be human readable
     *
     * @since ReduxFramework 0.2.0
     */
    function getVariants($var) {
        $result = array();
        $italic = array();
        foreach ($var as $v) {
            $name = "";
            if ($v[0] == 1) {
                $name = 'Ultra-Light 100';
            } else if ($v[0] == 2) {
                $name = 'Light 200';
            } else if ($v[0] == 3) {
                $name = 'Book 300';
            } else if ($v[0] == 4 || $v[0] == "r" || $v[0] == "i") {
                $name = 'Normal 400';
            } else if ($v[0] == 5) {
                $name = 'Medium 500';
            } else if ($v[0] == 6) {
                $name = 'Semi-Bold 600';
            } else if ($v[0] == 7) {
                $name = 'Bold 700';
            } else if ($v[0] == 8) {
                $name = 'Extra-Bold 800';
            } else if ($v[0] == 9) {
                $name = 'Ultra-Bold 900';
            }
            if ($v == "regular") {
                $v = "400";
            }
            if (strpos($v, "italic") || $v == "italic") {
                $name.= " Italic";
                $name = trim($name);
                if ($v == "italic") {
                    $v = "400italic";
                }
                $italic[] = array(
                    'id' => $v,
                    'name' => $name
                );
            } else {
                $result[] = array(
                    'id' => $v,
                    'name' => $name
                );
            }
        }
        
        foreach ($italic as $item) {
            $result[] = $item;
        }
        
        return array_filter($result);
    } //function
    
    
} //class
